@@ -10,6 +10,7 @@ Usage:
 # import compatibility functions and utilities
 import re
 import sys
+from html import escape
 from weakref import proxy
 
 # to inherit from the tqdm class
@@ -58,12 +59,6 @@ if True:  # pragma: no cover
     except ImportError:
         pass
 
-    # HTML encoding
-    try:  # Py3
-        from html import escape
-    except ImportError:  # Py2
-        from cgi import escape
-
 __author__ = {"github.com/": ["lrq3000", "casperdcl", "alexanderkuk"]}
 __all__ = ['tqdm_notebook', 'tnrange', 'tqdm', 'trange']
 WARN_NOIPYW = ("IProgress not found. Please update jupyter and ipywidgets."
@@ -85,7 +80,7 @@ class TqdmHBox(HBox):
     def __repr__(self, pretty=False):
         pbar = getattr(self, 'pbar', None)
         if pbar is None:
-            return super(TqdmHBox, self).__repr__()
+            return super().__repr__()
         return pbar.format_meter(**self._json_(pretty))
 
     def _repr_pretty_(self, pp, *_, **__):
@@ -162,6 +157,7 @@ class tqdm_notebook(std_tqdm):
         pbar.value = self.n
 
         if msg:
+            msg = msg.replace(' ', '\u2007')  # fix html space padding
             # html escape special characters (like '&')
             if '<bar/>' in msg:
                 left, right = map(escape, re.split(r'\|?<bar/>\|?', msg, maxsplit=1))
@@ -224,7 +220,7 @@ class tqdm_notebook(std_tqdm):
         kwargs['disable'] = bool(kwargs.get('disable', False))
         colour = kwargs.pop('colour', None)
         display_here = kwargs.pop('display', True)
-        super(tqdm_notebook, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         if self.disable or not kwargs['gui']:
             self.disp = lambda *_, **__: None
             return
@@ -250,10 +246,8 @@ class tqdm_notebook(std_tqdm):
 
     def __iter__(self):
         try:
-            it = super(tqdm_notebook, self).__iter__()
-            for obj in it:
-                # return super(tqdm...) will not catch exception
-                yield obj
+            it = super().__iter__()
+            yield from it
         # NB: except ... [ as ...] breaks IPython async KeyboardInterrupt
         except:  # NOQA
             self.disp(bar_style='danger')
@@ -263,7 +257,7 @@ class tqdm_notebook(std_tqdm):
 
     def update(self, n=1):
         try:
-            return super(tqdm_notebook, self).update(n=n)
+            return super().update(n=n)
         # NB: except ... [ as ...] breaks IPython async KeyboardInterrupt
         except:  # NOQA
             # cannot catch KeyboardInterrupt when using manual tqdm
@@ -276,7 +270,7 @@ class tqdm_notebook(std_tqdm):
     def close(self):
         if self.disable:
             return
-        super(tqdm_notebook, self).close()
+        super().close()
         # Try to detect if there was an error or KeyboardInterrupt
         # in manual mode: if n < total, things probably got wrong
         if self.total and self.n < self.total:
@@ -301,14 +295,14 @@ class tqdm_notebook(std_tqdm):
         total  : int or float, optional. Total to use for the new bar.
         """
         if self.disable:
-            return super(tqdm_notebook, self).reset(total=total)
+            return super().reset(total=total)
         _, pbar, _ = self.container.children
         pbar.bar_style = ''
         if total is not None:
             pbar.max = total
             if not self.total and self.ncols is None:  # no longer unknown total
                 pbar.layout.width = None  # reset width
-        return super(tqdm_notebook, self).reset(total=total)
+        return super().reset(total=total)
 
 
 def tnrange(*args, **kwargs):
